==> plugin_codelab_new-0.0.10.tar.gz: lib/pages/user_posts.dart <==
import 'package:flutter/services.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:flutter_screenutil/screenutil_init.dart';
import 'package:number_display/number_display.dart';
import 'package:plugin_codelab_new/bloc/feed_cubit.dart';
import 'package:plugin_codelab_new/models/post_model.dart';
import 'package:plugin_codelab_new/models/report_sub_type_model.dart';
import 'package:plugin_codelab_new/models/user_model.dart';
import 'package:plugin_codelab_new/widgets/loadingButtonIndicator.dart';
import 'package:plugin_codelab_new/widgets/post.dart';

class UserPost extends StatefulWidget {
  const UserPost({Key key, @required this.userData, @required this.currentUser})
      : super(key: key);

  final UserModel userData;
  final UserModel currentUser;
  @override
  _UserPostState createState() => _UserPostState();
}

class _UserPostState extends State<UserPost> {
  FeedCubit feedCubit;
  var _scrollController = ScrollController();
  @override
  void initState() {
    _scrollController.addListener(_onScroll);
    SystemChrome.setPreferredOrientations([
      DeviceOrientation.portraitDown,
      DeviceOrientation.portraitUp,
    ]);
    feedCubit = BlocProvider.of<FeedCubit>(context);
    super.initState();
  }

  void _onScroll() {
    if (_scrollController.position.pixels ==
        _scrollController.position.maxScrollExtent) {
      _getPostsList();
    }
  }

  final display = createDisplay(
    length: 4,
    separator: ',',
    decimal: 2,
  );
  double defaultScreenWidth = 393.0;
  double defaultScreenHeight = 534.0;
  List<PostModel> postsList = [];
  List<ReportSubTypeModel> reportsSubTypeList = [];
  int likeId;
  int dislikeId;
  int saveId;

  Future<List<PostModel>> _getPostsList() async {
    await getLikeSubId();
    postsList = await feedCubit.feedRepository
        .fetchPostsByUserId(this.widget.userData.id);

    return postsList;
  }

  Future getLikeSubId() async {
    reportsSubTypeList = await feedCubit.feedRepository.fetchAllSubType();
    for (var i = 0; i < reportsSubTypeList.length; i++) {
      if (likeId == null || dislikeId == null || saveId == null) {
        if (reportsSubTypeList[i].type == "Like") {
          likeId = reportsSubTypeList[i].id;
        } else if (reportsSubTypeList[i].type == "Dislike") {
          dislikeId = reportsSubTypeList[i].id;
        } else if (reportsSubTypeList[i].type == "Save") {
          saveId = reportsSubTypeList[i].id;
        }
      } else {
        break;
      }
    }
  }

  @override
  Widget build(BuildContext context) {
    var agentName = (this.widget.userData.firstName).toString() +
        " " +
        (this.widget.userData.lastName).toString();
    return ScreenUtilInit(
      designSize: Size(defaultScreenWidth, defaultScreenHeight),
      allowFontScaling: false,
      builder: () => LayoutBuilder(
        builder: (_, BoxConstraints constraints) {
          return MaterialApp(
            home: Scaffold(
              appBar: PreferredSize(
                  preferredSize: Size.fromHeight(70.0),
                  child: AppBar(
                    backgroundColor: Color(0xFF083356),
                    leading: GestureDetector(
                        onTap: () {
                          Navigator.of(context).popAndPushNamed("/homePage");
                        },
                        child: Icon(Icons.arrow_back, color: Colors.white)),
                    title: Padding(
                      padding: EdgeInsets.only(
                          left: ScreenUtil().setWidth(10),
                          top: ScreenUtil().setWidth(9)),
                      child: Text(
                        agentName.toString() + " post",
                        style: TextStyle(color: Colors.white),
                      ),
                    ),
                  )),
              body: FutureBuilder(
                future: _getPostsList(),
                builder: (context, projectSnap) {
                  if (projectSnap.connectionState == ConnectionState.waiting ||
                      projectSnap.connectionState == ConnectionState.none) {
                    return Center(child: LoadingIndicatorDark());
                  }
                  return Stack(children: [
                    RefreshIndicator(
                      onRefresh: () {
                        return _getPostsList();
                      },
                      child: ListView.separated(
                        cacheExtent: 9999,
                        padding: EdgeInsets.all(ScreenUtil().setWidth(8)),
                        itemCount: postsList.length,
                        itemBuilder: (BuildContext context, int index) {
                          PostModel post = projectSnap.data[index];
                          return FeedPost(
                            postData: post,
                            likeId: likeId,
                            dislikeId: dislikeId,
                            saveId: saveId,
                            currentUser: this.widget.currentUser,
                            images: post.attachedUrl.split(","),
                          );
                        },
                        separatorBuilder: (BuildContext context, int index) =>
                            const Divider(),
                      ),
                    ),
                  ]);
                },
              ),
            ),
          );
        },
      ),
    );
  }
}

==> plugin_codelab_new-0.0.15.tar.gz: lib/pages/user_posts.dart <==
import 'package:flutter/services.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:flutter_screenutil/screenutil_init.dart';
import 'package:number_display/number_display.dart';
import 'package:plugin_codelab_new/bloc/feed_cubit.dart';
import 'package:plugin_codelab_new/models/post_model.dart';
import 'package:plugin_codelab_new/models/report_sub_type_model.dart';
import 'package:plugin_codelab_new/models/user_model.dart';
import 'package:plugin_codelab_new/widgets/loadingButtonIndicator.dart';
import 'package:plugin_codelab_new/widgets/post.dart';

class UserPost extends StatefulWidget {
  const UserPost({Key key, @required this.userData, @required this.currentUser})
      : super(key: key);

  final UserModel userData;
  final UserModel currentUser;
  @override
  _UserPostState createState() => _UserPostState();
}

class _UserPostState extends State<UserPost> {
  FeedCubit feedCubit;
  var _scrollController = ScrollController();
  @override
  void initState() {
    _scrollController.addListener(_onScroll);
    SystemChrome.setPreferredOrientations([
      DeviceOrientation.portraitDown,
      DeviceOrientation.portraitUp,
    ]);
    feedCubit = BlocProvider.of<FeedCubit>(context);
    super.initState();
  }

  void _onScroll() {
    if (_scrollController.position.pixels ==
        _scrollController.position.maxScrollExtent) {
      _getPostsList();
    }
  }

  final display = createDisplay(
    length: 4,
    separator: ',',
    decimal: 2,
  );
  double defaultScreenWidth = 393.0;
  double defaultScreenHeight = 534.0;
  List<PostModel> postsList = [];
  List<ReportSubTypeModel> reportsSubTypeList = [];
  int likeId;
  int dislikeId;
  int saveId;

  Future<List<PostModel>> _getPostsList() async {
    await getLikeSubId();
    postsList = await feedCubit.feedRepository
        .fetchPostsByUserId(this.widget.userData.id);

    return postsList;
  }

  Future getLikeSubId() async {
    reportsSubTypeList = await feedCubit.feedRepository.fetchAllSubType();
    for (var i = 0; i < reportsSubTypeList.length; i++) {
      if (likeId == null || dislikeId == null || saveId == null) {
        if (reportsSubTypeList[i].type == "Like") {
          likeId = reportsSubTypeList[i].id;
        } else if (reportsSubTypeList[i].type == "Dislike") {
          dislikeId = reportsSubTypeList[i].id;
        } else if (reportsSubTypeList[i].type == "Save") {
          saveId = reportsSubTypeList[i].id;
        }
      } else {
        break;
      }
    }
  }

  @override
  Widget build(BuildContext context) {
    var agentName = (this.widget.userData.firstName).toString() +
        " " +
        (this.widget.userData.lastName).toString();
    return ScreenUtilInit(
      designSize: Size(defaultScreenWidth, defaultScreenHeight),
      allowFontScaling: false,
      builder: () => LayoutBuilder(
        builder: (_, BoxConstraints constraints) {
          return MaterialApp(
            home: Scaffold(
              appBar: PreferredSize(
                  preferredSize: Size.fromHeight(70.0),
                  child: AppBar(
                    backgroundColor: Color(0xFF083356),
                    leading: GestureDetector(
                        onTap: () {
                          Navigator.of(context).popAndPushNamed("/homePage");
                        },
                        child: Padding(
                          padding:
                              EdgeInsets.only(top: ScreenUtil().setWidth(9)),
                          child: Icon(Icons.arrow_back, color: Colors.white),
                        )),
                    title: Padding(
                      padding: EdgeInsets.only(
                          left: ScreenUtil().setWidth(10),
                          top: ScreenUtil().setWidth(9)),
                      child: Text(
                        agentName.toString() + " post",
                        style: TextStyle(color: Colors.white),
                      ),
                    ),
                  )),
              body: FutureBuilder(
                future: _getPostsList(),
                builder: (context, projectSnap) {
                  if (projectSnap.connectionState == ConnectionState.waiting ||
                      projectSnap.connectionState == ConnectionState.none) {
                    return Center(child: LoadingIndicatorDark());
                  }
                  return Stack(children: [
                    RefreshIndicator(
                      onRefresh: () {
                        return _getPostsList();
                      },
                      child: ListView.separated(
                        cacheExtent: 9999,
                        padding: EdgeInsets.all(ScreenUtil().setWidth(8)),
                        itemCount: postsList.length,
                        itemBuilder: (BuildContext context, int index) {
                          PostModel post = projectSnap.data[index];
                          return FeedPost(
                            postData: post,
                            likeId: likeId,
                            dislikeId: dislikeId,
                            saveId: saveId,
                            currentUser: this.widget.currentUser,
                            images: post.attachedUrl.split(","),
                          );
                        },
                        separatorBuilder: (BuildContext context, int index) =>
                            const Divider(),
                      ),
                    ),
                  ]);
                },
              ),
            ),
          );
        },
      ),
    );
  }
}
